@@ -547,6 +547,7 @@ OC.L10N.register(
     "Raise hand" : "Alzar la mano",
     "Lower hand" : "Baxar la mano",
     "This conversation is read-only" : "Esta conversación ye namás de llectura",
+    "Reload" : "Volver cargar",
     "{nickName} raised their hand." : "«{nickName}» alzo la mano",
     "A participant raised their hand." : "Un participante alzó la mano.",
     "Previous page of videos" : "Páxina de vídeos anterior",
@@ -687,6 +688,8 @@ OC.L10N.register(
     "Files" : "Ficheros",
     "(edited)" : "(editóse)",
     "The message has expired or has been deleted" : "El mensaxe caducó o desanicióse",
+    "24 hours" : "24 hores",
+    "7 days" : "7 díes",
     "Message text copied to clipboard" : "El testu del mensaxe copióse nel cartafueyu",
     "Message text could not be copied" : "El testu del mensaxe nun se pudo copiar",
     "A reminder was successfully removed" : "El recordatoriu quitóse correutamente",
@@ -709,6 +712,7 @@ OC.L10N.register(
     "Translate message" : "Traducir el mensaxe",
     "Translating" : "Traduciendo",
     "Copy translated text" : "Copiar el testu traducíu",
+    "Send now" : "Unviar agora",
     "Message sent" : "Unvióse'l mensaxe",
     "Deleting message" : "Desaniciando'l mensaxe",
     "An error occurred while deleting the message" : "Prodúxose un error mentanto se desaniciaba'l mensaxe",
@@ -726,6 +730,7 @@ OC.L10N.register(
     "Show all reactions" : "Amosar toles reaiciones",
     "Add more reactions" : "Amestar más reaiciones",
     "No messages" : "Nun hai nengún mensaxe",
+    "Unpin" : "Lliberar",
     "Add participants" : "Amestar participantes",
     "Conversation visibility" : "Visibilidá de la conversación",
     "This conversation has been locked" : "Bloquióse esta conversación",
@@ -734,6 +739,7 @@ OC.L10N.register(
     "The message could not be edited" : "Nun se pudo editar el mensaxe",
     "File upload is not available in this conversation" : "La xuba de ficheros nun ta disponible nesta conversación",
     "Add emoji" : "Amestar un fustaxe",
+    "Send later" : "Unviar dempués",
     "Smart picker" : "Selector intelixente",
     "New file" : "Ficheru nuevu",
     "Blank" : "Baleru",
@@ -817,7 +823,6 @@ OC.L10N.register(
     "Display name: {name}" : "Nome visible: {name}",
     "Save name" : "Guardar el nome",
     "Failed to save sounds setting" : "Nun se pue guardar la configuración de los soníos",
-    "Sounds setting saved" : "Guardóse la configuración de los soníos",
     "Error while saving sounds setting" : "Hebo un error mentanto se guardaba la configuración de soníu",
     "Notification settings" : "Configuración de los avisos",
     "Privacy" : "Privacidá",
@@ -947,13 +952,11 @@ OC.L10N.register(
     "Talk settings" : "Configuración de Talk",
     "Media settings" : "Configuración multimedia",
     "Normal call" : "Llamada normal",
-    "Code block copied to clipboard" : "El bloque de códigu copióse nel cartafueyu",
-    "Code block could not be copied" : "Nun se pudo copiar el bloque de códigu",
-    "Copy code block" : "Copiar el bloque de códigu",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
     "A week ago" : "Hai una selmana",
     "_%n day ago_::_%n days ago_" : ["Hai %n día","Hai %n díes"],
+    "Sounds setting saved" : "Guardóse la configuración de los soníos",
     "Browse …" : "Restolar…",
     "Appearance" : "Aspeutu",
     "Sounds" : "Soníos",
