@@ -357,6 +357,7 @@ OC.L10N.register(
     "Reset" : "Reiniciar",
     "Cancel" : "Cancelar",
     "Back" : "Atrás",
+    "Meeting" : "Reunión",
     "Loading …" : "Cargando …",
     "From" : "De",
     "To" : "Para",
@@ -367,6 +368,7 @@ OC.L10N.register(
     "Done" : "Terminado",
     "Exit full screen (F)" : "Salir de pantalla completa (F)",
     "Grid view" : "Vista de cuadrícula",
+    "Reload" : "Recargar",
     "Waiting for others to join the call …" : "Esperando a que los demás se unan a la llamada ...",
     "You can invite others in the participant tab of the sidebar" : "Puedes invitar a otras personas en la pestaña de participante del menú lateral",
     "You can invite others in the participant tab of the sidebar or share this link to invite others!" : "¡Puedes invitar a otros usando la pestaña de participante de la barra lateral o compartiendo esta liga para invitar a otras personas!",
@@ -390,7 +392,6 @@ OC.L10N.register(
     "Choose" : "Seleccionar",
     "The file must be a PNG or JPG" : "El archivo debe ser PNG o JPG",
     "Restricted" : "Restringido",
-    "Meeting" : "Reunión",
     "Personal" : "Personal",
     "Leave conversation" : "Dejar la conversación",
     "Delete conversation" : "Borrar conversación",
@@ -422,14 +423,17 @@ OC.L10N.register(
     "Blur" : "Difuminar",
     "Upload" : "Cargar",
     "Files" : "Archivos",
+    "24 hours" : "24 horas",
     "Reply" : "Responder",
     "More actions" : "Más acciones",
     "Set reminder" : "Establecer recordatorio",
     "Translate" : "Traducir",
     "Dismiss" : "Descartar",
     "Translate from" : "Traducir desde",
+    "Send now" : "Enviar ahora",
     "Contact" : "Contacto",
     "No messages" : "Sin mensajes",
+    "Send later" : "Enviar más tarde",
     "Share from Files" : "Compartir desde Archivos",
     "Upload from device" : "Cargar desde el dispositivo",
     "Create new poll" : "Crear nueva encuesta",
@@ -510,7 +514,6 @@ OC.L10N.register(
     "Set reminder for tomorrow" : "Configurar recordatorio para mañana",
     "Set reminder for this weekend" : "Configurar recordatorio para este fin de semana",
     "Set reminder for next week" : "Configurar recordatorio para la próxima semana",
-    "Copy code block" : "Copiar bloque de código",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "_%n day ago_::_%n days ago_" : ["hace %n día","hace %n días","hace %n días"],
