@@ -620,6 +620,7 @@ OC.L10N.register(
     "Back" : "Takaisin",
     "Add participant \"{user}\"" : "Lisää osallistuja \"{user}\"",
     "Now" : "Nyt",
+    "Meeting" : "Kokous",
     "Loading …" : "Ladataan…",
     "From" : "Lähettäjä",
     "To" : "Vastaanottaja",
@@ -638,6 +639,7 @@ OC.L10N.register(
     "Speaker view" : "Puhujan näkymä",
     "Grid view" : "Ruudukkonäkymä",
     "This conversation is read-only" : "Keskustelu on \"vain luku\"-tilassa",
+    "Reload" : "Päivitä",
     "{nickName} raised their hand." : "{nickName} nosti kätensä.",
     "A participant raised their hand." : "Osallistuja nosti kätensä.",
     "Previous page of videos" : "Videoiden edellinen sivu",
@@ -729,7 +731,6 @@ OC.L10N.register(
     "Participants can join calls, but cannot enable audio nor video nor share screen until a moderator manually grants them permissions." : "Osallistujat voivat liittyä puheluihin, mutta eivät voi ottaa ääntä tai videota käyttöön tai jakaa näyttönsä sisältöä, ennen kuin moderaattori on antanut siihen luvan.",
     "Advanced permissions" : "Edistyneet oikeudet",
     "Edit permissions" : "Muokkaa oikeuksia",
-    "Meeting" : "Kokous",
     "Conversation settings" : "Keskustelun asetukset",
     "Basic Info" : "Perustiedot",
     "Personal" : "Henkilökohtainen",
@@ -833,7 +834,7 @@ OC.L10N.register(
     "Clear filters" : "Tyhjennä suodattimet",
     "New personal note" : "Uusi henkilökohtainen muistiinpano",
     "Clear filter" : "Tyhjennä suodatin",
-    "Talk settings" : "Talk-asetukset",
+    "App settings" : "Sovelluksen asetukset",
     "Users" : "Käyttäjät",
     "Groups" : "Ryhmät",
     "Teams" : "Tiimit",
@@ -886,14 +887,8 @@ OC.L10N.register(
     "(edited)" : "(muokattu)",
     "The message has expired or has been deleted" : "Tämä viesti on vanhentunut tai se on poistettu",
     "Cancel quote" : "Peruuta lainaus",
-    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
-    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
-    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
-    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
-    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
-    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
-    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
-    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
+    "24 hours" : "24 tuntia",
+    "7 days" : "7 päivää",
     "Clear reminder – {timeLocale}" : "Tyhjennä muistutus – {timeLocale}",
     "Message text copied to clipboard" : "Viestin teksti kopioitu leikepöydälle",
     "Message text could not be copied" : "Viestin tekstiä ei voitu kopioida",
@@ -926,6 +921,7 @@ OC.L10N.register(
     "Translate to" : "Kohdekieli",
     "Translating" : "Käännetään",
     "Copy translated text" : "Kopioi käännetty teksti",
+    "Send now" : "Lähetä nyt",
     "Message read by everyone who shares their reading status" : "Viesti luettu kaikkien niiden kanssa, jotka jakavat lukutilapäivityksensä",
     "Message sent" : "Viesti lähetetty",
     "Deleting message" : "Poistetaan viestiä",
@@ -951,6 +947,7 @@ OC.L10N.register(
     "Show or collapse system messages" : "Näytä tai piilota järjestelmäviestit",
     "No messages" : "Ei viestejä",
     "All messages have expired or have been deleted." : "Kaikki viestit ovat vanhentuneet tai ne on poistettu.",
+    "Unpin" : "Poista kiinnitys",
     "Cancel search" : "Peruuta haku",
     "Add a phone number" : "Lisää puhelinnumero",
     "All set, the conversation \"{conversationName}\" was created." : "Kaikki valmista, keskustelu \"{conversationName}\" luotu.",
@@ -966,6 +963,7 @@ OC.L10N.register(
     "Send without notification" : "Lähetä ilman ilmoitusta",
     "File to share" : "Jaettava tiedosto",
     "Add emoji" : "Lisää emoji",
+    "Send later" : "Lähetä myöhemmin",
     "Cancel editing" : "Peruuta muokkaus",
     "Share from {nextcloud}" : "Jaa lähteestä {nextcloud}",
     "Share from Files" : "Jaa tiedostoista",
@@ -1100,9 +1098,7 @@ OC.L10N.register(
     "Save name" : "Tallenna nimi",
     "Select location for attachments" : "Valitse sijainti liitteille",
     "Error while setting attachment folder" : "Virhe asettaessa liitekansiota",
-    "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
     "Failed to save sounds setting" : "Ääniasetusten tallentaminen epäonnistui",
-    "Sounds setting saved" : "Ääniasetukset tallennettu",
     "Error while saving sounds setting" : "Virhe ääniasetuksia tallentaessa",
     "Play sounds when participants join or leave a call" : "Toista ääni kun osallistuja liittyy tai poistuu puhelusta",
     "Notification settings" : "Ilmoitusasetukset",
@@ -1252,6 +1248,10 @@ OC.L10N.register(
     "Failed to add reaction" : "Reaktion lisääminen epäonnistui",
     "Failed to remove reaction" : "Reaktion poistaminen epäonnistui",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ei tue täysin käyttämääsi selainta. Käytä uusinta versiota Mozilla Firefoxista, Microsoft Edgestä, Google Chromesta, Operasta tai Apple Safarista.",
+    "Later today – {timeLocale}" : "Myöhemmin tänään – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Huomenna – {timeLocale}",
+    "This weekend – {timeLocale}" : "Tämä viikonloppu – {timeLocale}",
+    "Next week – {timeLocale}" : "Ensi viikko – {timeLocale}",
     "Conversation link copied to clipboard" : "Keskustelulinkki kopioitu leikepöydälle",
     "The link could not be copied" : "Linkkiä ei voitu kopioida",
     "Please reload the page." : "Päivitä sivu.",
@@ -1285,6 +1285,7 @@ OC.L10N.register(
     "Click the button below to join." : "Napsauta alla olevaa painiketta liittyäksesi.",
     "Join »%s«" : "Liity »%s«",
     "Always show the device preview screen before joining a call in this conversation." : "Näytä aina laitteen esikatselunäkymä ennen liittymistä puheluun tässä keskustelussa.",
+    "Talk settings" : "Talk-asetukset",
     "Refresh devices list" : "Päivitä laitelista",
     "Media settings" : "Media-asetukset",
     "Always show preview for this conversation" : "Näytä aina esikatselu tälle keskustelulle",
@@ -1292,14 +1293,17 @@ OC.L10N.register(
     "The conversation participants will not be notified about this call" : "Keskustelun osallistujille ei ilmoiteta tästä puhelusta",
     "Normal call" : "Normaali puhelu",
     "The conversation participants will be notified about this call" : "Keskustelun osallistujille ilmoitetaan tästä puhelusta",
-    "Code block copied to clipboard" : "Koodilohko kopioitu leikepöydälle",
-    "Code block could not be copied" : "Koodilohkoa ei voitu kopioida",
-    "Copy code block" : "Kopioi koodilohko",
+    "Set reminder for later today" : "Aseta muistutus myöhemmälle ajankohdalle tälle päivälle",
+    "Set reminder for tomorrow" : "Aseta muistutus huomiselle",
+    "Set reminder for this weekend" : "Aseta muistutus tälle viikonlopulle",
+    "Set reminder for next week" : "Aseta muistutus seuraavalle viikolle",
     "Today" : "Tänään",
     "Yesterday" : "Eilen",
     "A week ago" : "Viikko sitten",
     "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
     "Choose the folder in which attachments should be saved." : "Valitse mihin kansioon liitteet tulee tallentaa.",
+    "Your privacy setting has been saved" : "Yksityisyysasetuksesi on tallennettu",
+    "Sounds setting saved" : "Ääniasetukset tallennettu",
     "Choose devices" : "Valitse laitteet",
     "Browse …" : "Selaa…",
     "Appearance" : "Ulkoasu",
