@@ -613,6 +613,7 @@ OC.L10N.register(
     "Cancel" : "Odustani",
     "Back" : "Natrag",
     "Add participant \"{user}\"" : "Dodaj sudionika „{user}”",
+    "Meeting" : "Sastanak",
     "Loading …" : "Učitavanje…",
     "From" : "Od",
     "To" : "Do",
@@ -628,6 +629,7 @@ OC.L10N.register(
     "Speaker view" : "Prikaz govornika",
     "Grid view" : "Prikaz rešetke",
     "This conversation is read-only" : "Ovaj razgovor je samo za čitanje",
+    "Reload" : "Ponovno učitaj",
     "{nickName} raised their hand." : "{nickName} je podigao ruku.",
     "A participant raised their hand." : "Sudionik je podigao ruku.",
     "Collapse stripe" : "Sakrij traku",
@@ -683,7 +685,6 @@ OC.L10N.register(
     "Restricted" : "Ograničeno",
     "Advanced permissions" : "Napredna dopuštenja",
     "Edit permissions" : "Uredi dopuštenja",
-    "Meeting" : "Sastanak",
     "Conversation settings" : "Postavke razgovora",
     "Personal" : "Osobno",
     "Matterbridge" : "Matterbridge",
@@ -753,7 +754,7 @@ OC.L10N.register(
     "Conversation list" : "Popis razgovora",
     "Unread messages" : "Nepročitane poruke",
     "Clear filter" : "Ukloni filtar",
-    "Talk settings" : "Postavke razgovora",
+    "App settings" : "Postavke aplikacije",
     "Users" : "Korisnici",
     "Groups" : "Grupe",
     "Open conversations" : "Otvori razgovore",
@@ -779,6 +780,7 @@ OC.L10N.register(
     "Invalid path selected" : "Odabran nevažeći put",
     "Upload" : "Otpremi",
     "Files" : "Datoteke",
+    "24 hours" : "24 sata",
     "Reply" : "Odgovori",
     "More actions" : "Dodatne radnje",
     "Reply privately" : "Odgovori privatno",
@@ -810,6 +812,7 @@ OC.L10N.register(
     "You are not allowed to share files" : "Nije vam dopušteno dijeliti datoteke",
     "You cannot send messages to this conversation at the moment" : "Trenutno ne možete slati poruke u ovaj razgovor",
     "No messages" : "Nema poruka",
+    "Unpin" : "Otkvači",
     "Create a new group conversation" : "Stvori novi grupni razgovor",
     "Add participants" : "Dodaj sudionike",
     "Allow guests to join via link" : "Dopusti pridruživanje gostiju putem pozivnice",
@@ -894,10 +897,8 @@ OC.L10N.register(
     "Select conversation" : "Odaberi razgovor",
     "Select location for attachments" : "Odaberite lokaciju privitaka",
     "Error while setting attachment folder" : "Pogreška pri postavljanju mape za privitke",
-    "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
     "Error while setting read status privacy" : "Pogreška pri postavljanju privatnosti statusa čitanja",
     "Failed to save sounds setting" : "Spremanje postavki zvukova nije uspjelo",
-    "Sounds setting saved" : "Postavka zvukova je spremljena",
     "Error while saving sounds setting" : "Pogreška pri spremanju postavke zvukova",
     "Play sounds when participants join or leave a call" : "Reproduciraj zvukove kad se sudionici pridruže ili napuste poziv",
     "Notification settings" : "Postavke obavijesti",
@@ -1027,9 +1028,6 @@ OC.L10N.register(
     "Error occurred when sending invitations" : "Došlo je do pogreške pri slanju pozivnica",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Nextcloud Talk ne podržava trenutni preglednik. Preuzmite najnoviju inačicu preglednika Mozilla Firefox, Microsoft Edge, Google Chrome, Opera ili Apple Safari.",
     "Lost connection to signaling server. Trying to reconnect." : "Veza sa signalnim poslužiteljem je prekinuta. Pokušavam se ponovno povezati.",
-    "Establishing signaling connection is taking longer than expected …" : "Uspostavljanje signalne veze traje duže od očekivanog…",
-    "Failed to establish signaling connection. Retrying …" : "Signalna veza nije uspostavljena. Pokušavam ponovo…",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Signalna veza nije uspostavljena. Nešto nije u redu u konfiguraciji signalnog poslužitelja",
     "Please reload the page." : "Ponovno učitajte stranicu.",
     "Do not disturb" : "Ne ometaj",
     "Away" : "Odsutan",
@@ -1058,10 +1056,13 @@ OC.L10N.register(
     "Click the button below to join." : "Kliknite gumb ispod za pridruživanje.",
     "Join »%s«" : "Pridruži se »%s«",
     "Always show the device preview screen before joining a call in this conversation." : "Uvijek prikažite zaslon za pretpregled uređaja prije pridruživanja pozivu u ovom razgovoru.",
+    "Talk settings" : "Postavke razgovora",
     "Today" : "Danas",
     "Yesterday" : "Jučer",
     "_%n day ago_::_%n days ago_" : ["Prije %n dana","Prije %n dana","Prije %n dana"],
     "Choose the folder in which attachments should be saved." : "Odaberite mapu za spremanje privitaka.",
+    "Your privacy setting has been saved" : "Postavka privatnosti je spremljena",
+    "Sounds setting saved" : "Postavka zvukova je spremljena",
     "Choose devices" : "Odaberi uređaje",
     "Appearance" : "Izgled",
     "Share my read-status and show the read-status of others" : "Dijeli moj status čitanja i prikaži statuse čitanja drugih sudionika",
@@ -1074,6 +1075,9 @@ OC.L10N.register(
     "Blur background" : "Zamuti pozadinu",
     "Sharing your screen only works with Firefox version 52 or newer." : "Dijeljenje zaslona moguće je samo u pregledniku Firefox, inačice 52 ili novije.",
     "Screensharing extension is required to share your screen." : "Za dijeljenje zaslona potrebno je instalirati proširenje za dijeljenje zaslona.",
-    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome."
+    "Please use a different browser like Firefox or Chrome to share your screen." : "Koristite se nekim drugim preglednikom za dijeljenje zaslona, primjerice preglednikom Firefox ili Chrome.",
+    "Establishing signaling connection is taking longer than expected …" : "Uspostavljanje signalne veze traje duže od očekivanog…",
+    "Failed to establish signaling connection. Retrying …" : "Signalna veza nije uspostavljena. Pokušavam ponovo…",
+    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Signalna veza nije uspostavljena. Nešto nije u redu u konfiguraciji signalnog poslužitelja"
 },
 "nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
