@@ -393,9 +393,10 @@ OC.L10N.register(
     "OK" : "Labi",
     "Confirm" : "Apstiprināt",
     "Reset" : "Atiestatīt",
-    "Back" : "Atpakaļ",
     "Cancel" : "Atcelt",
+    "Back" : "Atpakaļ",
     "Now" : "Tagad",
+    "Meeting" : "Tikšanās",
     "Loading …" : "Ielādē…",
     "From" : "No",
     "To" : "Līdz",
@@ -428,12 +429,11 @@ OC.L10N.register(
     "Choose" : "Izvēlēties",
     "The file must be a PNG or JPG" : "Datnei jābūt PNG vai JPG",
     "Restricted" : "Ierobežota",
-    "Meeting" : "Tikšanās",
     "Personal" : "Personīgs",
     "Setup overview" : "Uzstādīšanas pārskats",
     "Leave conversation" : "Atstāt sarunu",
-    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
     "Delete conversation" : "Izdzēst sarunu",
+    "Once a conversation is left, to rejoin a closed conversation, an invite is needed. An open conversation can be rejoined at any time." : "Tiklīdz saruna ir pamesta, lai pievienotos slēgtai sarunai, ir nepieciešams uzaicinājums. Atvērtai sarunai var jebkurā brīdī pievienoties no jauna.",
     "_%n hour_::_%n hours_" : ["%n stundu","%n stunda","%n stundas"],
     "Password protection" : "Password protection",
     "Open conversation" : "Atvērt sarunu",
@@ -443,6 +443,7 @@ OC.L10N.register(
     "Join" : "Pievienoties",
     "Hello, {displayName}" : "Sveiciens, {displayName}!",
     "Create and copy link" : "Izveidot saiti un ievietot starpliktuvē",
+    "Open calendar" : "Atvērt kalendāru",
     "Log in" : "Pieteikties",
     "Remove from favorites" : "Noņemt no izlases",
     "Add to favorites" : "Pievienot izlasei",
@@ -450,6 +451,7 @@ OC.L10N.register(
     "Home" : "Sākums",
     "You have no unread mentions." : "Nav nelasītu pieminēšanu.",
     "Clear filter" : "Notīrīt atlasi",
+    "App settings" : "Lietotnes iestatījumi",
     "Users" : "Lietotāji",
     "Groups" : "Grupas",
     "Teams" : "Komandas",
@@ -460,8 +462,8 @@ OC.L10N.register(
     "Invalid path selected" : "Atlasīts nederīgs ceļš",
     "Upload" : "Augšupielādēt",
     "Files" : "Datnes",
-    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
-    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
+    "24 hours" : "24 stundas",
+    "7 days" : "7 dienas",
     "Message forwarded to \"Note to self\"" : "Ziņojums pārvirzīts uz “Piezīme sev”",
     "Error while forwarding message to \"Note to self\"" : "Kļūda ziņojuma pārvirzīšanas uz “Piezīme sev” laikā",
     "Reply" : "Atbildēt",
@@ -486,6 +488,7 @@ OC.L10N.register(
     "Add teams" : "Pievienot komandas",
     "Searching …" : "Meklē...",
     "Participants" : "Dalībnieki",
+    "Open chat" : "Atvērt tērzēšanu",
     "Chat" : "Tērzēt",
     "Details" : "Informācija",
     "From User" : "No lietotāja",
@@ -495,9 +498,8 @@ OC.L10N.register(
     "Select conversation" : "Izvēlēties sarunu",
     "Error while setting read status privacy" : "Kļūda lasīšanas stāvokļa privātuma iestatīšanas laikā",
     "Error while setting typing status privacy" : "Kļūda rakstīšanas stāvokļa privātuma iestatīšanas laikā",
-    "Appearance" : "Izskats",
+    "Notification settings" : "Paziņojumu iestatījumi",
     "Privacy" : "Privātums",
-    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Search" : "Meklēt",
     "Start call" : "Sākt zvanu",
     "All tasks done!" : "Visi uzdevumi paveikti.",
@@ -537,6 +539,7 @@ OC.L10N.register(
     "You and {user0} left the call" : "Tu un {user0} pametāt zvanu",
     "Search in conversation: {conversation}" : "Meklēt sarunā: {conversation}",
     "Error while sharing file" : "Kļūda datnes kopīgošanā",
+    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
     "Please reload the page." : "Lūgums pārlādēt lapu",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Tas aizņem vairāk laika, nekā paredzēts. Vai multivides atļaujas jau ir piešķirtas (vai noraidītas)? Ja atbilde ir “jā”, lūgums palaist savu pārlūku no jauna, jo ir skaņas un video atteice",
     "Access to microphone & camera is only possible with HTTPS" : "Piekļuve mikrofonam un kamerai ir iespējama izmantojot tikai HTTPS",
@@ -559,9 +562,12 @@ OC.L10N.register(
     "You were invited to a conversation." : "Tu uzaicinājāt uz sarunu.",
     "Click the button below to join." : "Jāklikšķina uz zemāk esošās pogas, lai pievienotos.",
     "Join »%s«" : "Pievienoties »%s«",
+    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
     "Today" : "Šodien",
     "Yesterday" : "Vakar",
     "_%n day ago_::_%n days ago_" : ["pirms %n dienām","pirms %n dienas","pirms %n dienām"],
+    "Appearance" : "Izskats",
+    "Keyboard shortcuts" : "Tastatūras saīsnes",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ekrāna koplietošana darbojas tikai ar Firefox 52. vai jaunāku versiju.",
     "Screensharing extension is required to share your screen." : "Ir nepieciešams ekrāna kopīgošanas paplašinājums, lai kopīgotu savu ekrānu.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Lūgums izmantot citu pārlūku, piemēram, Firefox vai Chrome, lai kopīgotu savu ekrānu."
