@@ -494,6 +494,7 @@ OC.L10N.register(
     "Assign" : "Atribuie",
     "Add participant \"{user}\"" : "Adaugă participant \"{user}\"",
     "Now" : "Acum",
+    "Meeting" : "Videoconferință",
     "From" : "De la",
     "To" : "Către",
     "Calendar" : "Calendar",
@@ -511,6 +512,7 @@ OC.L10N.register(
     "Speaker view" : "Vizualizare vorbitor",
     "Grid view" : "Afișare în grilă",
     "This conversation is read-only" : "Această conversație este read-only",
+    "Reload" : "Reîncarcă",
     "{nickName} raised their hand." : "{nickName} a ridicat mâna.",
     "A participant raised their hand." : "Un participant a ridicat mâna.",
     "Connecting …" : "Se conectează ...",
@@ -573,7 +575,6 @@ OC.L10N.register(
     "Restricted" : "Restricționat",
     "Advanced permissions" : "Permisiuni avansate",
     "Edit permissions" : "Editare permisiuni",
-    "Meeting" : "Videoconferință",
     "Conversation settings" : "Configurația conversației",
     "Basic Info" : "Informații de bază",
     "Personal" : "Personal",
@@ -633,7 +634,6 @@ OC.L10N.register(
     "Clear filters" : "Șterge filtrele",
     "New personal note" : "Notă personală nouă",
     "Clear filter" : "Șterge filtrul",
-    "Talk settings" : "Setări Talk",
     "Users" : "Utilizatori",
     "Groups" : "Grupuri",
     "Open conversations" : "Conversații deschise",
@@ -649,14 +649,7 @@ OC.L10N.register(
     "Blur" : "Blurează",
     "Upload" : "Încărcare",
     "Files" : "Fișiere",
-    "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
-    "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
-    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
-    "Set reminder for tomorrow" : "Setează memo pentru mâine",
-    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
-    "Set reminder for this weekend" : "Setează memo pentru acest weekend",
-    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
-    "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
+    "24 hours" : "24 de ore",
     "Clear reminder – {timeLocale}" : "Șterge memento – {timeLocale}",
     "Reply" : "Răspunde",
     "More actions" : "Mai multe acțiuni",
@@ -665,6 +658,7 @@ OC.L10N.register(
     "Translate" : "Tradu",
     "Set custom reminder" : "Setează memento particular",
     "Dismiss" : "Elimină",
+    "Send now" : "Trimite acum",
     "Message sent" : "Mesajul a fost transmis",
     "Contact" : "Contact",
     "{stack} in {board}" : "{stack} în {board}",
@@ -677,6 +671,7 @@ OC.L10N.register(
     "Enter password" : "Introduceți parola",
     "Joining conversation …" : "Alăturare la conversație ...",
     "File to share" : "Fișier de partajat",
+    "Send later" : "Trimite mai târziu",
     "Cancel editing" : "Anulează editarea",
     "Share from Files" : "Partajează din Fișiere",
     "Upload from device" : "Încarcă din dispozitiv",
@@ -740,11 +735,9 @@ OC.L10N.register(
     "Save name" : "Salvează numele",
     "Select location for attachments" : "Selectați locația atașamentelor",
     "Error while setting attachment folder" : "Eroare la setarea dosarului pentru atașamente",
-    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
     "Error while setting read status privacy" : "Eroare la setarea confidențialității statusului de citire",
     "Error while setting typing status privacy" : "Eroare la setarea confidențialității tastării",
     "Failed to save sounds setting" : "Eroare la salvarea setărilor de sunet",
-    "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Error while saving sounds setting" : "Eroare la salvarea setărilor de sunet",
     "Play sounds when participants join or leave a call" : "Avertizează sonor când cineva se alătură sau părăsește o videoconferință",
     "Notification settings" : "Setări notificări",
@@ -856,6 +849,10 @@ OC.L10N.register(
     "Failed to add reaction" : "Eroare la adăugarea reacției",
     "Failed to remove reaction" : "Eroare la ștergerea reacției",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Browserul folosit nu este compatibil cu Nextcloud Talk. Folosiți ultima versiune a Mozilla Firefox, Microsoft Edge, Google Chrome sau Apple Safari.",
+    "Later today – {timeLocale}" : "Azi, mai târziu – {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Mâine – {timeLocale}",
+    "This weekend – {timeLocale}" : "În acest weekend – {timeLocale}",
+    "Next week – {timeLocale}" : "Săptămâna viitoare– {timeLocale}",
     "Conversation link copied to clipboard" : "Linkul conversației a fost copiat",
     "The link could not be copied" : "Linkul nu s-a putut copia",
     "Please reload the page." : "Te rugăm să reîncarci pagina.",
@@ -875,10 +872,17 @@ OC.L10N.register(
     "Click the button below to join." : "Apăsați butonul pentru a vă alătura.",
     "Join »%s«" : "Alăturați-vă »%s«",
     "Always show the device preview screen before joining a call in this conversation." : "Arată întotdeauna o previzualizare a ecranului dispozitvului înainte de a participa la această conversație.",
+    "Talk settings" : "Setări Talk",
+    "Set reminder for later today" : "Setează memo pentru azi, mai târziu",
+    "Set reminder for tomorrow" : "Setează memo pentru mâine",
+    "Set reminder for this weekend" : "Setează memo pentru acest weekend",
+    "Set reminder for next week" : "Setează memo pentru săptămâna viitoare",
     "Today" : "Azi",
     "Yesterday" : "Ieri",
     "_%n day ago_::_%n days ago_" : ["%n zi în rumă","Acum %n zile","Acum %n zile"],
     "Choose the folder in which attachments should be saved." : "Selectați folderul în care se vor salva atașamentele",
+    "Your privacy setting has been saved" : "Setările de confidențialitate au fost salvate",
+    "Sounds setting saved" : "Setările de sunet au fost salvate",
     "Choose devices" : "Selectați dispozitivele",
     "Browse …" : "Navigare ...",
     "Appearance" : "Aspect",
