@@ -192,6 +192,7 @@ OC.L10N.register(
     "No results" : "Asnjë rezultat",
     "Done" : "U bë",
     "Grid view" : "Pamje galeri",
+    "Reload" : "Ringarkoje",
     "Waiting for others to join the call …" : "Duke pritur që të tjerët t'i bashkohen thirrjes ...",
     "Copy link" : "Kopjo linkun",
     "Mute audio" : "Mute audio",
@@ -225,6 +226,8 @@ OC.L10N.register(
     "Devices" : "Pajisjet",
     "Upload" : "Ngarkoni",
     "Files" : "Skedarët",
+    "24 hours" : "24 orë",
+    "7 days" : "7 ditë ",
     "Reply" : "Përgjigju",
     "More actions" : "Më tepër veprime ",
     "Translate" : "Përkthe",
