@@ -343,9 +343,10 @@ OC.L10N.register(
     "Federated user" : "Người dùng được liên kết",
     "Confirm" : "Xác nhận",
     "Reset" : "Đặt lại",
-    "Back" : "Quay lại",
     "Cancel" : "Hủy",
+    "Back" : "Quay lại",
     "Add participant \"{user}\"" : "Thêm người tham gia \"{user}\"",
+    "Meeting" : "Cuộc họp",
     "Loading …" : "Đang tải …",
     "From" : "Từ",
     "To" : "Tới",
@@ -360,6 +361,7 @@ OC.L10N.register(
     "Speaker view" : "Chế độ xem người gọi điện",
     "Grid view" : "Xem dạng Lưới",
     "This conversation is read-only" : "Cuộc trò chuyện này ở chế độ chỉ đọc",
+    "Reload" : "Tải lại",
     "{nickName} raised their hand." : "{nickName} giơ tay.",
     "A participant raised their hand." : "Một người tham gia giơ tay.",
     "Collapse stripe" : "Thu gọi sọc",
@@ -403,15 +405,14 @@ OC.L10N.register(
     "Choose" : "Chọn",
     "The file must be a PNG or JPG" : "Tệp phải là PNG hoặc JPG",
     "Restricted" : "Bị giới hạn",
-    "Meeting" : "Cuộc họp",
     "Conversation settings" : "Cài đặt cuộc trò chuyện",
     "Personal" : "Cá nhân",
     "Danger zone" : "Khu vực nguy hiểm",
+    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
+    "Delete conversation" : "Xóa cuộc trò chuyện",
     "Do you really want to delete \"{displayName}\"?" : "Bạn có thực sự muốn xóa \"{displayName}\" không?",
     "Error while deleting conversation" : "Lỗi khi xóa cuộc trò chuyện",
     "Be careful, these actions cannot be undone." : "Hãy cẩn thận, không thể hoàn tác những hành động này.",
-    "Leave conversation" : "Rời khỏi cuộc đàm thoại",
-    "Delete conversation" : "Xóa cuộc trò chuyện",
     "Password protection" : "Password protection",
     "Set a password" : "Đặt mật khẩu",
     "Save password" : "Lưu mật khẩu",
@@ -459,7 +460,6 @@ OC.L10N.register(
     "Conversation list" : "Danh sách cuộc trò chuyện",
     "Unread messages" : "Tin nhắn chưa đọc",
     "Clear filter" : "Xóa bộ lọc",
-    "Talk settings" : "Cài đặt Talk",
     "Users" : "Người dùng",
     "Groups" : "Nhóm",
     "Open conversations" : "Mở cuộc trò chuyện",
@@ -481,6 +481,15 @@ OC.L10N.register(
     "Invalid path selected" : "Đường dẫn đã chọn không hợp lệ",
     "Upload" : "Tải lên",
     "Files" : "Tệp",
+    "24 hours" : "24 tiếng",
+    "Reply" : "Trả l",
+    "More actions" : "Nhiều hành động hơn",
+    "Set reminder" : "Thiết lập nhắc nhở",
+    "Reply privately" : "Trả lời riêng tư",
+    "Copy message link" : "Sao chép liên kết tin nhắn",
+    "Go to file" : "Tới tập tin",
+    "Translate" : "Dịch",
+    "Dismiss" : "Bỏ qua",
     "Message read by everyone who shares their reading status" : "Tin nhắn được đọc bởi tất cả những người chia sẻ trạng thái đọc của họ",
     "Message sent" : "Tin nhắn đã gửi",
     "Deleting message" : "Đang xóa tin nhắn",
@@ -488,17 +497,6 @@ OC.L10N.register(
     "Message could not be deleted because it is too old" : "Không thể xóa tin nhắn vì nó quá cũ",
     "Only normal chat messages can be deleted" : "Chỉ những tin nhắn trò chuyện bình thường mới có thể bị xóa",
     "An error occurred while deleting the message" : "Đã xảy ra lỗi khi xóa tin nhắn",
-    "Later today – {timeLocale}" : "Sau này - {timeLocale}",
-    "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
-    "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
-    "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
-    "Reply" : "Trả l",
-    "Set reminder" : "Thiết lập nhắc nhở",
-    "Reply privately" : "Trả lời riêng tư",
-    "Copy message link" : "Sao chép liên kết tin nhắn",
-    "Go to file" : "Tới tập tin",
-    "Translate" : "Dịch",
-    "Dismiss" : "Bỏ qua",
     "Contact" : "Liên hệ",
     "{stack} in {board}" : "{stack} trong {board}",
     "Deck Card" : "Thẻ bài",
@@ -559,26 +557,18 @@ OC.L10N.register(
     "Edit display name" : "Chỉnh sửa tên hiển thị",
     "Select location for attachments" : "Chọn vị trí cho tệp đính kèm",
     "Error while setting attachment folder" : "Lỗi khi cấu hình thư mục tệp đính kèm",
-    "Your privacy setting has been saved" : "Các thiết lập quyền riêng tư của bạn đã được lưu",
     "Error while setting read status privacy" : "Lỗi khi đặt quyền riêng tư của trạng thái đã đọc",
     "Failed to save sounds setting" : "Không thể lưu cài đặt âm thanh",
-    "Attachments folder" : "Thư mục đính kèm",
-    "Appearance" : "Ngoại hình",
+    "Notification settings" : "Cài đặt thông báo",
     "Privacy" : "Bảo mật",
-    "Share my read-status and show the read-status of others" : "Chia sẻ trạng thái đã đọc của tôi và hiển thị trạng thái đã đọc của những người khác",
-    "Sounds" : "Âm thanh",
-    "Keyboard shortcuts" : "Phím tắt",
-    "Speed up your Talk experience with these quick shortcuts." : "Tăng tốc trải nghiệm Talk của bạn bằng các phím tắt nhanh này.",
+    "Attachments folder" : "Thư mục đính kèm",
+    "Search" : "Tìm",
     "Focus the chat input" : "Tập trung vào đầu vào trò chuyện",
     "Unfocus the chat input to use shortcuts" : "Bỏ tập trung vào đầu vào trò chuyện để sử dụng các phím tắt",
-    "Fullscreen the chat or call" : "Toàn màn hình cuộc trò chuyện hoặc cuộc gọi",
-    "Search" : "Tìm",
     "Shortcuts while in a call" : "Các phím tắt khi đang gọi điện",
     "Microphone on and off" : "Bật và tắt micrô",
-    "Space bar" : "Thanh dấu cách",
-    "Push to talk or push to mute" : "Nhấn để nói hoặc tắt tiếng",
     "Raise or lower hand" : "Giơ tay hoặc hạ tay",
-    "More actions" : "Nhiều hành động hơn",
+    "Push to talk or push to mute" : "Nhấn để nói hoặc tắt tiếng",
     "Start call" : "Bắt đầu cuộc gọi",
     "You will be able to join the call only after a moderator starts it." : "Bạn sẽ chỉ có thể tham gia cuộc gọi sau khi người kiểm duyệt bắt đầu cuộc gọi.",
     "Screensharing options" : "Tùy chọn chia sẻ màn hình",
@@ -662,6 +652,7 @@ OC.L10N.register(
     "Show all files" : "Hiện tất cả tệp",
     "Default" : "Mặc định",
     "Group" : "Nhóm",
+    "Team" : "Đội",
     "You: {lastMessage}" : "Bạn: {lastMessage}",
     "You are trying to join a conversation while having an active session in another window or device. This is currently not supported by Nextcloud Talk. What do you want to do?" : "Bạn đang cố gắng tham gia một cuộc trò chuyện trong khi có một phiên hoạt động trong một cửa sổ hoặc thiết bị khác. Điều này hiện không được vWorkspace Talk hỗ trợ. Bạn muốn làm gì?",
     "Leave this page" : "Rời khỏi trang này",
@@ -684,10 +675,11 @@ OC.L10N.register(
     "Invitations sent" : "Lời mời đã được gửi",
     "Error occurred when sending invitations" : "Đã xảy ra lỗi khi gửi lời mời",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome, Opera or Apple Safari." : "Trình duyệt bạn đang sử dụng không được vWorkspace Talk hỗ trợ đầy đủ. Vui lòng sử dụng phiên bản mới nhất của Mozilla Firefox, Microsoft Edge, Google Chrome, Opera hoặc Apple Safari.",
+    "Later today – {timeLocale}" : "Sau này - {timeLocale}",
+    "Tomorrow – {timeLocale}" : "Ngày mai - {timeLocale}",
+    "This weekend – {timeLocale}" : "Cuối tuần này - {timeLocale}",
+    "Next week – {timeLocale}" : "Tuần sau - {timeLocale}",
     "Lost connection to signaling server. Trying to reconnect." : "Mất kết nối với máy chủ báo hiệu. Đang cố gắng kết nối lại.",
-    "Establishing signaling connection is taking longer than expected …" : "Việc thiết lập kết nối báo hiệu mất nhiều thời gian hơn dự kiến…",
-    "Failed to establish signaling connection. Retrying …" : "Không thiết lập được kết nối tín hiệu. Đang thử lại…",
-    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Không thiết lập được kết nối tín hiệu. Có thể có gì đó sai trong cấu hình máy chủ báo hiệu",
     "Please reload the page." : "Vui lòng tải lại trang.",
     "Do not disturb" : "Đừng làm phiền",
     "Away" : "Tạm vắng",
@@ -711,24 +703,27 @@ OC.L10N.register(
     "__language_name__" : "Tiếng Việt",
     "Tasks" : "Nhiệm vụ",
     "Notes" : "Ghi chú",
-    "You tried to call {user}" : "Bạn đã cố gắng gọi {user}",
     "%s invited you to a conversation." : "%s đã được mời vào cuộc trò chuyện",
     "You were invited to a conversation." : "Bạn đã được mời vào cuộc trò chuyện",
     "Click the button below to join." : "Click vào nút bên dưới để tham gia",
     "Join »%s«" : "Tham gia »%s«",
-    "{user} invited you to a private conversation" : "{user} đã mời bạn tham gia cuộc trò chuyện riêng",
-    "Copy conversation link" : "Sao chép liên kết cuộc trò chuyện",
+    "Talk settings" : "Cài đặt Talk",
     "Today" : "Hôm nay",
     "Yesterday" : "Hôm qua",
-    "Close" : "Đóng",
+    "Your privacy setting has been saved" : "Các thiết lập quyền riêng tư của bạn đã được lưu",
     "Choose devices" : "Chọn thiết bị",
-    "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "vWorkspace Talk đã được cập nhật, bạn cần tải lại trang trước khi có thể bắt đầu hoặc tham gia cuộc gọi.",
+    "Appearance" : "Ngoại hình",
+    "Share my read-status and show the read-status of others" : "Chia sẻ trạng thái đã đọc của tôi và hiển thị trạng thái đã đọc của những người khác",
+    "Sounds" : "Âm thanh",
+    "Keyboard shortcuts" : "Phím tắt",
+    "Speed up your Talk experience with these quick shortcuts." : "Tăng tốc trải nghiệm Talk của bạn bằng các phím tắt nhanh này.",
+    "Fullscreen the chat or call" : "Toàn màn hình cuộc trò chuyện hoặc cuộc gọi",
+    "Space bar" : "Thanh dấu cách",
     "Sharing your screen only works with Firefox version 52 or newer." : "Chia sẻ màn hình của bạn chỉ hoạt động với Firefox phiên bản 52 trở lên.",
     "Screensharing extension is required to share your screen." : "Cần có tiện ích mở rộng để chia sẻ màn hình của bạn.",
     "Please use a different browser like Firefox or Chrome to share your screen." : "Vui lòng sử dụng một trình duyệt khác như Firefox hoặc Chrome để chia sẻ màn hình của bạn.",
-    "Nextcloud Talk was updated, please reload the page" : "vWorkspace Talk đã được cập nhật, vui lòng tải lại trang",
-    "Failed to join the conversation. Try to reload the page." : "Không tham gia được cuộc trò chuyện. Hãy thử tải lại trang.",
-    "Nextcloud is in maintenance mode, please reload the page" : "vWorkspace đang ở chế độ bảo trì, vui lòng tải lại trang",
-    "Lost connection to signaling server. Try to reload the page manually." : "Mất kết nối với máy chủ báo hiệu. Cố gắng tải lại trang theo cách thủ công."
+    "Establishing signaling connection is taking longer than expected …" : "Việc thiết lập kết nối báo hiệu mất nhiều thời gian hơn dự kiến…",
+    "Failed to establish signaling connection. Retrying …" : "Không thiết lập được kết nối tín hiệu. Đang thử lại…",
+    "Failed to establish signaling connection. Something might be wrong in the signaling server configuration" : "Không thiết lập được kết nối tín hiệu. Có thể có gì đó sai trong cấu hình máy chủ báo hiệu"
 },
 "nplurals=1; plural=0;");
