@@ -97,6 +97,7 @@ use OCA\Talk\Listener\GroupMembershipListener;
 use OCA\Talk\Listener\NoteToSelfListener;
 use OCA\Talk\Listener\RestrictStartingCalls as RestrictStartingCallsListener;
 use OCA\Talk\Listener\SampleConversationsListener;
+use OCA\Talk\Listener\ThreadListener;
 use OCA\Talk\Listener\UserDeletedListener;
 use OCA\Talk\Maps\MapsPluginLoader;
 use OCA\Talk\Middleware\CanUseTalkMiddleware;
@@ -121,6 +122,7 @@ use OCA\Talk\SetupCheck\BackgroundBlurLoading;
 use OCA\Talk\SetupCheck\Configuration;
 use OCA\Talk\SetupCheck\FederationLockCache;
 use OCA\Talk\SetupCheck\HighPerformanceBackend;
+use OCA\Talk\SetupCheck\NotifyPush;
 use OCA\Talk\SetupCheck\RecordingBackend;
 use OCA\Talk\SetupCheck\SIPConfiguration;
 use OCA\Talk\Share\Listener as ShareListener;
@@ -175,6 +177,7 @@ class Application extends App implements IBootstrap {
 		parent::__construct(self::APP_ID, $urlParams);
 	}
 
+	#[\Override]
 	public function register(IRegistrationContext $context): void {
 		$context->registerMiddleWare(CanUseTalkMiddleware::class);
 		$context->registerMiddleWare(InjectionMiddleware::class);
@@ -327,6 +330,8 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(ChatMessageSentEvent::class, SignalingListener::class);
 		$context->registerEventListener(SystemMessageSentEvent::class, SignalingListener::class);
 		$context->registerEventListener(SystemMessagesMultipleSentEvent::class, SignalingListener::class);
+		$context->registerEventListener(ReactionAddedEvent::class, SignalingListener::class);
+		$context->registerEventListener(ReactionRemovedEvent::class, SignalingListener::class);
 
 		// Signaling listeners (Both)
 		$context->registerEventListener(BeforeRoomDeletedEvent::class, SignalingListener::class);
@@ -339,6 +344,9 @@ class Application extends App implements IBootstrap {
 		$context->registerEventListener(GuestJoinedRoomEvent::class, SignalingListener::class);
 		$context->registerEventListener(UserJoinedRoomEvent::class, SignalingListener::class);
 
+		// Threads listeners
+		$context->registerEventListener(AttendeesRemovedEvent::class, ThreadListener::class);
+
 		// Video verification
 		$context->registerEventListener(BeforeUserJoinedRoomEvent::class, PublicShareAuthListener::class);
 		$context->registerEventListener(BeforeGuestJoinedRoomEvent::class, PublicShareAuthListener::class);
@@ -370,11 +378,13 @@ class Application extends App implements IBootstrap {
 		$context->registerSetupCheck(Configuration::class);
 		$context->registerSetupCheck(HighPerformanceBackend::class);
 		$context->registerSetupCheck(FederationLockCache::class);
+		$context->registerSetupCheck(NotifyPush::class);
 		$context->registerSetupCheck(RecordingBackend::class);
 		$context->registerSetupCheck(SIPConfiguration::class);
 		$context->registerSetupCheck(BackgroundBlurLoading::class);
 	}
 
+	#[\Override]
 	public function boot(IBootContext $context): void {
 		$context->injectFn([$this, 'registerCollaborationResourceProvider']);
 		$context->injectFn([$this, 'registerClientLinks']);
