@@ -428,7 +428,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 * for the follow-up query.
 	 *
 	 * @param 0|1 $lookIntoFuture Polling for new messages (1) or getting the history of the chat (0)
-	 * @param int $limit Number of chat messages to receive (100 by default, 200 at most)
+	 * @param int<1, 200> $limit Number of chat messages to receive (100 by default, 200 at most)
 	 * @param int $lastKnownMessageId The last known message (serves as offset)
 	 * @psalm-param non-negative-int $lastKnownMessageId
 	 * @param int $lastCommonReadId The last known common read message
@@ -469,7 +469,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		int $markNotificationsAsRead = 1,
 		int $threadId = 0,
 	): DataResponse {
-		$limit = min(200, $limit);
+		$limit = min(200, max(1, $limit));
 		$timeout = min(30, $timeout);
 
 		if ($this->room->isFederatedConversation()) {
@@ -816,7 +816,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 *
 	 * @param int $messageId The focused message which should be in the "middle" of the returned context
 	 * @psalm-param non-negative-int $messageId
-	 * @param int<1, 100> $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
+	 * @param int<0, 100> $limit Number of chat messages to receive in both directions (50 by default, 100 at most, might return 201 messages)
 	 * @param int $threadId Limit the chat message list to a given thread
 	 * @psalm-param non-negative-int $threadId
 	 * @return DataResponse<Http::STATUS_OK, list<TalkChatMessageWithParent>, array{'X-Chat-Last-Common-Read'?: numeric-string, X-Chat-Last-Given?: numeric-string}>|DataResponse<Http::STATUS_NOT_MODIFIED, null, array{}>
@@ -839,7 +839,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		int $limit = 50,
 		int $threadId = 0,
 	): DataResponse {
-		$limit = min(100, $limit);
+		$limit = min(100, max(0, $limit));
 
 		if ($this->room->isFederatedConversation()) {
 			/** @var \OCA\Talk\Federation\Proxy\TalkV1\Controller\ChatController $proxy */
@@ -858,9 +858,16 @@ class ChatController extends AEnvironmentAwareOCSController {
 			// Guest in a fully expired chat, no history, just loading the chat from beginning for now
 			$commentsHistory = $commentsFuture = [];
 		} else {
-			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $limit, true, $threadId);
+			// Load at least 1 history entry to get the includeLastKnown
+			$historyLimit = max(1, $limit);
+			$commentsHistory = $this->chatManager->getHistory($this->room, $messageId, $historyLimit, true, $threadId);
 			$commentsHistory = array_reverse($commentsHistory);
-			$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false, threadId: $threadId);
+			if ($limit === 0) {
+				// No context requested, only the known message
+				$commentsFuture = [];
+			} else {
+				$commentsFuture = $this->chatManager->waitForNewMessages($this->room, $messageId, $limit, 0, $currentUser, false, threadId: $threadId);
+			}
 		}
 
 		return $this->prepareCommentsAsDataResponse(array_merge($commentsHistory, $commentsFuture));
@@ -1571,7 +1578,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 			return $proxy->getObjectsSharedInRoomOverview($this->room, $this->participant, $limit);
 		}
 
-		$limit = min(20, $limit);
+		$limit = min(20, max(1, $limit));
 
 		$objectTypes = [
 			Attachment::TYPE_AUDIO,
@@ -1668,7 +1675,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		}
 
 		$offset = max(0, $lastKnownMessageId);
-		$limit = min(200, $limit);
+		$limit = min(200, max(1, $limit));
 
 		$attachments = $this->attachmentService->getAttachmentsByType($this->room, $objectType, $offset, $limit);
 		$messageIds = array_map(static fn (Attachment $attachment): int => $attachment->getMessageId(), $attachments);
