@@ -20,6 +20,7 @@ use OCA\Talk\Service\ParticipantService;
  * @psalm-import-type TalkPoll from ResponseDefinitions
  * @psalm-import-type TalkPollDraft from ResponseDefinitions
  * @psalm-import-type TalkReaction from ResponseDefinitions
+ * @psalm-import-type TalkThreadInfo from ResponseDefinitions
  */
 class UserConverter {
 	/**
@@ -85,9 +86,15 @@ class UserConverter {
 		if ($parameter['type'] === 'user') { // RichObjectDefinition, not Attendee::ACTOR_USERS
 			if (!isset($parameter['server'])) {
 				$parameter['server'] = $room->getRemoteServer();
+				if (!isset($parameter['mention-id'])) {
+					$parameter['mention-id'] = $parameter['id'];
+				}
 			} elseif ($parameter['server']) {
 				$localParticipants = $this->getLocalParticipants($room);
 				$cloudId = $this->createCloudIdFromUserIdAndFullServerUrl($parameter['id'], $parameter['server']);
+				if (!isset($parameter['mention-id'])) {
+					$parameter['mention-id'] = 'federated_user/' . $parameter['id'] . '@' . $parameter['server'];
+				}
 				if (isset($localParticipants[$cloudId])) {
 					unset($parameter['server']);
 					$parameter['name'] = $localParticipants[$cloudId]['displayName'];
@@ -96,6 +103,21 @@ class UserConverter {
 		} elseif ($parameter['type'] === 'call' && $parameter['id'] === $room->getRemoteToken()) {
 			$parameter['id'] = $room->getToken();
 			$parameter['icon-url'] = $this->avatarService->getAvatarUrl($room);
+			if (!isset($parameter['mention-id'])) {
+				$parameter['mention-id'] = 'all';
+			}
+		} elseif ($parameter['type'] === 'circle') {
+			if (!isset($parameter['mention-id'])) {
+				$parameter['mention-id'] = 'team/' . $parameter['id'];
+			}
+		} elseif ($parameter['type'] === 'user-group') {
+			if (!isset($parameter['mention-id'])) {
+				$parameter['mention-id'] = 'group/' . $parameter['id'];
+			}
+		} elseif ($parameter['type'] === 'email' || $parameter['type'] === 'guest') {
+			if (!isset($parameter['mention-id'])) {
+				$parameter['mention-id'] = $parameter['type'] . '/' . $parameter['id'];
+			}
 		}
 		return $parameter;
 	}
@@ -137,6 +159,34 @@ class UserConverter {
 		);
 	}
 
+	/**
+	 * @param Room $room
+	 * @param TalkThreadInfo $threadInfo
+	 * @return TalkThreadInfo
+	 */
+	public function convertThreadInfo(Room $room, array $threadInfo): array {
+		$threadInfo['thread']['roomToken'] = $room->getToken();
+		if (isset($threadInfo['first'])) {
+			$threadInfo['first'] = $this->convertMessageParameters($room, $threadInfo['first']);
+		}
+		if (isset($threadInfo['last'])) {
+			$threadInfo['last'] = $this->convertMessageParameters($room, $threadInfo['last']);
+		}
+		return $threadInfo;
+	}
+
+	/**
+	 * @param Room $room
+	 * @param list<TalkThreadInfo> $threadInfos
+	 * @return list<TalkThreadInfo>
+	 */
+	public function convertThreadInfos(Room $room, array $threadInfos): array {
+		return array_map(
+			fn (array $threadInfo): array => $this->convertThreadInfo($room, $threadInfo),
+			$threadInfos
+		);
+	}
+
 	/**
 	 * @template T of TalkPoll|TalkPollDraft
 	 * @param Room $room
