@@ -12,8 +12,12 @@ use OCA\Talk\Vendor\CuyZ\Valinor\Type\Type;
 /** @internal */
 final class Argument
 {
+    /** @var non-empty-string */
     private string $name;
 
+    /** @var non-empty-string */
+    private string $signature;
+
     private Type $type;
 
     private mixed $defaultValue = null;
@@ -22,15 +26,20 @@ final class Argument
 
     private Attributes $attributes;
 
-    public function __construct(string $name, Type $type)
+    /**
+     * @param non-empty-string $name
+     * @param non-empty-string $signature
+     */
+    public function __construct(string $name, string $signature, Type $type)
     {
-        $this->type = $type;
         $this->name = $name;
+        $this->signature = $signature;
+        $this->type = $type;
     }
 
     public static function fromParameter(ParameterDefinition $parameter): self
     {
-        $instance = new self($parameter->name, $parameter->type);
+        $instance = new self($parameter->name, $parameter->signature, $parameter->type);
         $instance->attributes = $parameter->attributes;
 
         if ($parameter->isOptional) {
@@ -43,7 +52,7 @@ final class Argument
 
     public static function fromProperty(PropertyDefinition $property): self
     {
-        $instance = new self($property->name, $property->type);
+        $instance = new self($property->name, $property->signature, $property->type);
         $instance->attributes = $property->attributes;
 
         if ($property->hasDefaultValue) {
@@ -54,11 +63,22 @@ final class Argument
         return $instance;
     }
 
+    /**
+     * @return non-empty-string
+     */
     public function name(): string
     {
         return $this->name;
     }
 
+    /**
+     * @return non-empty-string
+     */
+    public function signature(): string
+    {
+        return $this->signature;
+    }
+
     public function type(): Type
     {
         return $this->type;
