@@ -1,6 +1,13 @@
 <?php
-/** @var $_ array */
-/** @var $l \OCP\IL10N */
+
+declare(strict_types=1);
+/**
+ * SPDX-FileCopyrightText: 2023 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
+ */
+
+/** @var array $_ */
+/** @var \OCP\IL10N $l */
 \OCP\Util::addStyle('core', 'publicshareauth');
 \OCP\Util::addScript('core', 'publicshareauth');
 ?>
